--- old/usr/src/lib/libm/common/LD/sinl.c	2019-06-06 20:38:24.799300084 +0000
+++ new/usr/src/lib/libm/common/LD/sinl.c	2019-06-06 20:38:24.816938841 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,8 +30,9 @@
 
 #pragma weak __sinl = sinl
 
-/* INDENT OFF */
-/* sinl(x)
+/* BEGIN CSTYLED */
+/*
+ * sinl(x)
  * Table look-up algorithm by K.C. Ng, November, 1989.
  *
  * kernel function:
@@ -60,7 +62,7 @@
  * Accuracy:
  *	computer TRIG(x) returns trig(x) nearly rounded.
  */
-/* INDENT ON */
+/* END CSTYLED */
 
 #include "libm.h"
 #include "longdouble.h"
@@ -68,42 +70,47 @@
 #include <sys/isa_defs.h>
 
 long double
-sinl(long double x) {
+sinl(long double x)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
+
 #if defined(__i386) || defined(__amd64)
-	int *px = (int *) &x;
+	int *px = (int *)&x;
 #endif
 
 	/* sin(Inf or NaN) is NaN */
 	if (!finitel(x))
-		return x - x;
+		return (x - x);
 
 	/* High word of x. */
 #if defined(__i386) || defined(__amd64)
 	XTOI(px, ix);
 #else
-	ix = *(int *) &x;
+	ix = *(int *)&x;
 #endif
 	/* |x| ~< pi/4 */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)
-		return __k_sinl(x, z);
 
+	if (ix <= 0x3ffe9220) {
+		return (__k_sinl(x, z));
+	}
 	/* argument reduction needed */
 	else {
 		n = __rem_pio2l(x, y);
+
 		switch (n & 3) {
 		case 0:
-			return __k_sinl(y[0], y[1]);
+			return (__k_sinl(y[0], y[1]));
 		case 1:
-			return __k_cosl(y[0], y[1]);
+			return (__k_cosl(y[0], y[1]));
 		case 2:
-			return -__k_sinl(y[0], y[1]);
+			return (-__k_sinl(y[0], y[1]));
 		case 3:
-			return -__k_cosl(y[0], y[1]);
-		/* NOTREACHED */
+			return (-__k_cosl(y[0], y[1]));
+			/* NOTREACHED */
 		}
 	}
-	return 0.0L;
+
+	return (0.0L);
 }
